<?php
	/*=======================================================================
	 * copyright (c) AL-Design Works 
	 * http://cms.al-design.jp/
	 * このソースファイルは CMS Designer の一部です。
	 * 詳しいライセンス規約についてはウェブサイトを参照してください。
	 *=======================================================================
	 */

	require_once( dirname(__FILE__) . "/app.php.inc" );

	/* --------------------------------------------------------------------
	 * フォーム入力項目基本クラス。
	 * 
	 */ 
	class BaseEntryItem
	{
		var $dataName = '';
		var $dataType = '';
		var $dataCaption = '';
		var $dataDescription = '';
		
		var $entryName = '';
		var $entryId = '';
		
		var $errorMessage = '';
		var $initData = ''; // 初期値（スキーマで指定する）

		/* ----------------------------------------------------------------
		 * コンストラクタ。
		 * $xmlSchemaData : 対応するスキーマDataのXML要素。
		 */
		function __construct( $xmlSchemaData, $entryName, $entryId )
		{
			$this->dataName = $xmlSchemaData->get_attribute('name');
			$this->dataType = $xmlSchemaData->get_attribute('type');
			$this->dataCaption =  file2code( $xmlSchemaData->get_attribute('caption') );
			$this->dataDescription = file2code( $xmlSchemaData->get_attribute('description') );
			
			
			$this->entryName = $entryName;
			$this->entryId = $entryId;
			
			// チェック
			if ( empty( $this->dataName ) )
			{
				cmsd_abort_proc( "スキーマ項目定義エラー：'name'属性がありません。" );
			}
			
			if ( empty( $this->dataType ) )
			{
				cmsd_abort_proc( "スキーマ項目定義エラー：項目'" . $this->dataName .  "'にtype属性がありません。" );
			}

			if ( empty( $this->dataCaption ) )
			{
				cmsd_abort_proc( "スキーマ項目定義エラー：項目'" . $this->dataName .  "'にcaption属性がありません。" );
			}
			
			$initData = $xmlSchemaData->get_attribute('initdata');
			if ( $initData !== "" )
			{
				$this->initData = $initData;
			}
						
		}
		
		/* ----------------------------------------------------------------
		 * エラーメッセージの取得。
		 */
		function getErrorMessage()
		{
			return $this->errorMessage;
		}
		

		/* ----------------------------------------------------------------
		 * 当項目のXMLノードを新規作成する。
		 * $xmlDocParentEntry : エントリのDOMオブジェクト。
		 * $setInitData : 初期値。trueが指定されていた場合、スキーマで指定された値が設定される。デフォルト値はtrue。
		 * return : 新規XMLノード。
		 */
		function createNew( $xmlDocParentEntry, $setInitData = true )
		{
			$newNode = $xmlDocParentEntry->create_element( $this->dataName );
			
			if ( $setInitData ){
				$newNode->set_content( fileconv( $this->initData ) );
			}
			
			return $newNode;
		}
		
		/* ----------------------------------------------------------------
		 * 当項目のデータ項目名を返す。
		 * return : データ項目名。
		 */
		function getName()
		{
			return $this->dataName;
		}
		
		/* ----------------------------------------------------------------
		 * 当項目のデータ型名を返す。
		 * return : データ型名。
		 */
		function getType()
		{
			return $this->dataType;
		}
		
	}
	




?>